# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/monitor/proto/system_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/monitor/proto/system_status.proto',
  package='apollo.monitor',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/monitor/proto/system_status.proto\x12\x0e\x61pollo.monitor\x1a!modules/common/proto/header.proto\"\xa2\x01\n\x0f\x43omponentStatus\x12?\n\x06status\x18\x01 \x01(\x0e\x32&.apollo.monitor.ComponentStatus.Status:\x07UNKNOWN\x12\x0f\n\x07message\x18\x02 \x01(\t\"=\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x08\n\x04WARN\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\t\n\x05\x46\x41TAL\x10\x04\"\xd8\x02\n\tComponent\x12\x30\n\x07summary\x18\x01 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus\x12\x37\n\x0eprocess_status\x18\x02 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus\x12\x37\n\x0e\x63hannel_status\x18\x03 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus\x12\x38\n\x0fresource_status\x18\x04 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus\x12\x35\n\x0cother_status\x18\x05 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus\x12\x36\n\rmodule_status\x18\x06 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus\"\x8a\x05\n\x0cSystemStatus\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x41\n\x0bhmi_modules\x18\x07 \x03(\x0b\x32,.apollo.monitor.SystemStatus.HmiModulesEntry\x12@\n\ncomponents\x18\x08 \x03(\x0b\x32,.apollo.monitor.SystemStatus.ComponentsEntry\x12\x15\n\rpassenger_msg\x18\x04 \x01(\t\x12 \n\x18safety_mode_trigger_time\x18\x05 \x01(\x01\x12\x1e\n\x16require_emergency_stop\x18\x06 \x01(\x08\x12!\n\x19is_realtime_in_simulation\x18\t \x01(\x08\x12K\n\x10other_components\x18\n \x03(\x0b\x32\x31.apollo.monitor.SystemStatus.OtherComponentsEntry\x1aR\n\x0fHmiModulesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus:\x02\x38\x01\x1aL\n\x0f\x43omponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.apollo.monitor.Component:\x02\x38\x01\x1aW\n\x14OtherComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus:\x02\x38\x01J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])



_COMPONENTSTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='apollo.monitor.ComponentStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=198,
  serialized_end=259,
)
_sym_db.RegisterEnumDescriptor(_COMPONENTSTATUS_STATUS)


_COMPONENTSTATUS = _descriptor.Descriptor(
  name='ComponentStatus',
  full_name='apollo.monitor.ComponentStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.monitor.ComponentStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='apollo.monitor.ComponentStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPONENTSTATUS_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=259,
)


_COMPONENT = _descriptor.Descriptor(
  name='Component',
  full_name='apollo.monitor.Component',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary', full_name='apollo.monitor.Component.summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_status', full_name='apollo.monitor.Component.process_status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_status', full_name='apollo.monitor.Component.channel_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_status', full_name='apollo.monitor.Component.resource_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_status', full_name='apollo.monitor.Component.other_status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_status', full_name='apollo.monitor.Component.module_status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=606,
)


_SYSTEMSTATUS_HMIMODULESENTRY = _descriptor.Descriptor(
  name='HmiModulesEntry',
  full_name='apollo.monitor.SystemStatus.HmiModulesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.monitor.SystemStatus.HmiModulesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.monitor.SystemStatus.HmiModulesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1080,
)

_SYSTEMSTATUS_COMPONENTSENTRY = _descriptor.Descriptor(
  name='ComponentsEntry',
  full_name='apollo.monitor.SystemStatus.ComponentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.monitor.SystemStatus.ComponentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.monitor.SystemStatus.ComponentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1158,
)

_SYSTEMSTATUS_OTHERCOMPONENTSENTRY = _descriptor.Descriptor(
  name='OtherComponentsEntry',
  full_name='apollo.monitor.SystemStatus.OtherComponentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.monitor.SystemStatus.OtherComponentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.monitor.SystemStatus.OtherComponentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1160,
  serialized_end=1247,
)

_SYSTEMSTATUS = _descriptor.Descriptor(
  name='SystemStatus',
  full_name='apollo.monitor.SystemStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.monitor.SystemStatus.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hmi_modules', full_name='apollo.monitor.SystemStatus.hmi_modules', index=1,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='components', full_name='apollo.monitor.SystemStatus.components', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passenger_msg', full_name='apollo.monitor.SystemStatus.passenger_msg', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safety_mode_trigger_time', full_name='apollo.monitor.SystemStatus.safety_mode_trigger_time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_emergency_stop', full_name='apollo.monitor.SystemStatus.require_emergency_stop', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_realtime_in_simulation', full_name='apollo.monitor.SystemStatus.is_realtime_in_simulation', index=6,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_components', full_name='apollo.monitor.SystemStatus.other_components', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SYSTEMSTATUS_HMIMODULESENTRY, _SYSTEMSTATUS_COMPONENTSENTRY, _SYSTEMSTATUS_OTHERCOMPONENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=1259,
)

_COMPONENTSTATUS.fields_by_name['status'].enum_type = _COMPONENTSTATUS_STATUS
_COMPONENTSTATUS_STATUS.containing_type = _COMPONENTSTATUS
_COMPONENT.fields_by_name['summary'].message_type = _COMPONENTSTATUS
_COMPONENT.fields_by_name['process_status'].message_type = _COMPONENTSTATUS
_COMPONENT.fields_by_name['channel_status'].message_type = _COMPONENTSTATUS
_COMPONENT.fields_by_name['resource_status'].message_type = _COMPONENTSTATUS
_COMPONENT.fields_by_name['other_status'].message_type = _COMPONENTSTATUS
_COMPONENT.fields_by_name['module_status'].message_type = _COMPONENTSTATUS
_SYSTEMSTATUS_HMIMODULESENTRY.fields_by_name['value'].message_type = _COMPONENTSTATUS
_SYSTEMSTATUS_HMIMODULESENTRY.containing_type = _SYSTEMSTATUS
_SYSTEMSTATUS_COMPONENTSENTRY.fields_by_name['value'].message_type = _COMPONENT
_SYSTEMSTATUS_COMPONENTSENTRY.containing_type = _SYSTEMSTATUS
_SYSTEMSTATUS_OTHERCOMPONENTSENTRY.fields_by_name['value'].message_type = _COMPONENTSTATUS
_SYSTEMSTATUS_OTHERCOMPONENTSENTRY.containing_type = _SYSTEMSTATUS
_SYSTEMSTATUS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_SYSTEMSTATUS.fields_by_name['hmi_modules'].message_type = _SYSTEMSTATUS_HMIMODULESENTRY
_SYSTEMSTATUS.fields_by_name['components'].message_type = _SYSTEMSTATUS_COMPONENTSENTRY
_SYSTEMSTATUS.fields_by_name['other_components'].message_type = _SYSTEMSTATUS_OTHERCOMPONENTSENTRY
DESCRIPTOR.message_types_by_name['ComponentStatus'] = _COMPONENTSTATUS
DESCRIPTOR.message_types_by_name['Component'] = _COMPONENT
DESCRIPTOR.message_types_by_name['SystemStatus'] = _SYSTEMSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComponentStatus = _reflection.GeneratedProtocolMessageType('ComponentStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSTATUS,
  '__module__' : 'modules.monitor.proto.system_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.monitor.ComponentStatus)
  })
_sym_db.RegisterMessage(ComponentStatus)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENT,
  '__module__' : 'modules.monitor.proto.system_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.monitor.Component)
  })
_sym_db.RegisterMessage(Component)

SystemStatus = _reflection.GeneratedProtocolMessageType('SystemStatus', (_message.Message,), {

  'HmiModulesEntry' : _reflection.GeneratedProtocolMessageType('HmiModulesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SYSTEMSTATUS_HMIMODULESENTRY,
    '__module__' : 'modules.monitor.proto.system_status_pb2'
    # @@protoc_insertion_point(class_scope:apollo.monitor.SystemStatus.HmiModulesEntry)
    })
  ,

  'ComponentsEntry' : _reflection.GeneratedProtocolMessageType('ComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SYSTEMSTATUS_COMPONENTSENTRY,
    '__module__' : 'modules.monitor.proto.system_status_pb2'
    # @@protoc_insertion_point(class_scope:apollo.monitor.SystemStatus.ComponentsEntry)
    })
  ,

  'OtherComponentsEntry' : _reflection.GeneratedProtocolMessageType('OtherComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SYSTEMSTATUS_OTHERCOMPONENTSENTRY,
    '__module__' : 'modules.monitor.proto.system_status_pb2'
    # @@protoc_insertion_point(class_scope:apollo.monitor.SystemStatus.OtherComponentsEntry)
    })
  ,
  'DESCRIPTOR' : _SYSTEMSTATUS,
  '__module__' : 'modules.monitor.proto.system_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.monitor.SystemStatus)
  })
_sym_db.RegisterMessage(SystemStatus)
_sym_db.RegisterMessage(SystemStatus.HmiModulesEntry)
_sym_db.RegisterMessage(SystemStatus.ComponentsEntry)
_sym_db.RegisterMessage(SystemStatus.OtherComponentsEntry)


_SYSTEMSTATUS_HMIMODULESENTRY._options = None
_SYSTEMSTATUS_COMPONENTSENTRY._options = None
_SYSTEMSTATUS_OTHERCOMPONENTSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/probabilistic_fusion_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/probabilistic_fusion_config.proto',
  package='apollo.perception.fusion',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:modules/perception/proto/probabilistic_fusion_config.proto\x12\x18\x61pollo.perception.fusion\"\xa3\x03\n\x19ProbabilisticFusionConfig\x12\x17\n\tuse_lidar\x18\x01 \x01(\x08:\x04true\x12\x17\n\tuse_radar\x18\x02 \x01(\x08:\x04true\x12\x18\n\nuse_camera\x18\x03 \x01(\x08:\x04true\x12\"\n\x0etracker_method\x18\x04 \x01(\t:\nPbfTracker\x12.\n\x17\x64\x61ta_association_method\x18\x05 \x01(\t:\rHMAssociation\x12)\n\x12gate_keeper_method\x18\x06 \x01(\t:\rPbfGatekeeper\x12\x1b\n\x13prohibition_sensors\x18\x07 \x03(\t\x12(\n\x1amax_lidar_invisible_period\x18\x08 \x01(\x01:\x04\x30.25\x12\'\n\x1amax_radar_invisible_period\x18\t \x01(\x01:\x03\x30.5\x12)\n\x1bmax_camera_invisible_period\x18\n \x01(\x01:\x04\x30.75\x12 \n\x14max_cached_frame_num\x18\x0b \x01(\x03:\x02\x35\x30'
)




_PROBABILISTICFUSIONCONFIG = _descriptor.Descriptor(
  name='ProbabilisticFusionConfig',
  full_name='apollo.perception.fusion.ProbabilisticFusionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_lidar', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.use_lidar', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_radar', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.use_radar', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_camera', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.use_camera', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracker_method', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.tracker_method', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"PbfTracker".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_association_method', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.data_association_method', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"HMAssociation".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gate_keeper_method', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.gate_keeper_method', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"PbfGatekeeper".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prohibition_sensors', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.prohibition_sensors', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lidar_invisible_period', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.max_lidar_invisible_period', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_radar_invisible_period', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.max_radar_invisible_period', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_camera_invisible_period', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.max_camera_invisible_period', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.75),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_cached_frame_num', full_name='apollo.perception.fusion.ProbabilisticFusionConfig.max_cached_frame_num', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=True, default_value=50,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=508,
)

DESCRIPTOR.message_types_by_name['ProbabilisticFusionConfig'] = _PROBABILISTICFUSIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProbabilisticFusionConfig = _reflection.GeneratedProtocolMessageType('ProbabilisticFusionConfig', (_message.Message,), {
  'DESCRIPTOR' : _PROBABILISTICFUSIONCONFIG,
  '__module__' : 'modules.perception.proto.probabilistic_fusion_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.fusion.ProbabilisticFusionConfig)
  })
_sym_db.RegisterMessage(ProbabilisticFusionConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/microphone/proto/microphone_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/microphone/proto/microphone_config.proto',
  package='apollo.drivers.microphone.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8modules/drivers/microphone/proto/microphone_config.proto\x12 apollo.drivers.microphone.config\"\xf4\x02\n\x10MicrophoneConfig\x12\\\n\x10microphone_model\x18\x02 \x01(\x0e\x32\x42.apollo.drivers.microphone.config.MicrophoneConfig.MicrophoneModel\x12\r\n\x05\x63hunk\x18\x03 \x01(\x05\x12\x13\n\x0bsample_rate\x18\x04 \x01(\x02\x12\x16\n\x0erecord_seconds\x18\x05 \x01(\x02\x12\x14\n\x0csample_width\x18\x06 \x01(\x05\x12\x14\n\x0c\x63hannel_name\x18\x07 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x08 \x01(\t\x12\x14\n\x0cmic_distance\x18\t \x01(\x02\x12\x43\n\x0c\x63hannel_type\x18\x01 \x03(\x0e\x32-.apollo.drivers.microphone.config.ChannelType\"-\n\x0fMicrophoneModel\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tRESPEAKER\x10\x01*:\n\x0b\x43hannelType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x41SR\x10\x01\x12\x07\n\x03RAW\x10\x02\x12\x0c\n\x08PLAYBACK\x10\x03'
)

_CHANNELTYPE = _descriptor.EnumDescriptor(
  name='ChannelType',
  full_name='apollo.drivers.microphone.config.ChannelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAYBACK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=469,
  serialized_end=527,
)
_sym_db.RegisterEnumDescriptor(_CHANNELTYPE)

ChannelType = enum_type_wrapper.EnumTypeWrapper(_CHANNELTYPE)
UNKNOWN = 0
ASR = 1
RAW = 2
PLAYBACK = 3


_MICROPHONECONFIG_MICROPHONEMODEL = _descriptor.EnumDescriptor(
  name='MicrophoneModel',
  full_name='apollo.drivers.microphone.config.MicrophoneConfig.MicrophoneModel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESPEAKER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=422,
  serialized_end=467,
)
_sym_db.RegisterEnumDescriptor(_MICROPHONECONFIG_MICROPHONEMODEL)


_MICROPHONECONFIG = _descriptor.Descriptor(
  name='MicrophoneConfig',
  full_name='apollo.drivers.microphone.config.MicrophoneConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='microphone_model', full_name='apollo.drivers.microphone.config.MicrophoneConfig.microphone_model', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='apollo.drivers.microphone.config.MicrophoneConfig.chunk', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='apollo.drivers.microphone.config.MicrophoneConfig.sample_rate', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record_seconds', full_name='apollo.drivers.microphone.config.MicrophoneConfig.record_seconds', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_width', full_name='apollo.drivers.microphone.config.MicrophoneConfig.sample_width', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='apollo.drivers.microphone.config.MicrophoneConfig.channel_name', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.microphone.config.MicrophoneConfig.frame_id', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mic_distance', full_name='apollo.drivers.microphone.config.MicrophoneConfig.mic_distance', index=7,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='apollo.drivers.microphone.config.MicrophoneConfig.channel_type', index=8,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MICROPHONECONFIG_MICROPHONEMODEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=467,
)

_MICROPHONECONFIG.fields_by_name['microphone_model'].enum_type = _MICROPHONECONFIG_MICROPHONEMODEL
_MICROPHONECONFIG.fields_by_name['channel_type'].enum_type = _CHANNELTYPE
_MICROPHONECONFIG_MICROPHONEMODEL.containing_type = _MICROPHONECONFIG
DESCRIPTOR.message_types_by_name['MicrophoneConfig'] = _MICROPHONECONFIG
DESCRIPTOR.enum_types_by_name['ChannelType'] = _CHANNELTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MicrophoneConfig = _reflection.GeneratedProtocolMessageType('MicrophoneConfig', (_message.Message,), {
  'DESCRIPTOR' : _MICROPHONECONFIG,
  '__module__' : 'modules.drivers.microphone.proto.microphone_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.microphone.config.MicrophoneConfig)
  })
_sym_db.RegisterMessage(MicrophoneConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_speed_control.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_speed_control.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/map/proto/map_speed_control.proto\x12\x0c\x61pollo.hdmap\x1a$modules/map/proto/map_geometry.proto\"Y\n\x0cSpeedControl\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x07polygon\x18\x02 \x01(\x0b\x32\x15.apollo.hdmap.Polygon\x12\x13\n\x0bspeed_limit\x18\x03 \x01(\x01\"B\n\rSpeedControls\x12\x31\n\rspeed_control\x18\x01 \x03(\x0b\x32\x1a.apollo.hdmap.SpeedControl'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,])




_SPEEDCONTROL = _descriptor.Descriptor(
  name='SpeedControl',
  full_name='apollo.hdmap.SpeedControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.hdmap.SpeedControl.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='apollo.hdmap.SpeedControl.polygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.hdmap.SpeedControl.speed_limit', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=186,
)


_SPEEDCONTROLS = _descriptor.Descriptor(
  name='SpeedControls',
  full_name='apollo.hdmap.SpeedControls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed_control', full_name='apollo.hdmap.SpeedControls.speed_control', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=254,
)

_SPEEDCONTROL.fields_by_name['polygon'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._POLYGON
_SPEEDCONTROLS.fields_by_name['speed_control'].message_type = _SPEEDCONTROL
DESCRIPTOR.message_types_by_name['SpeedControl'] = _SPEEDCONTROL
DESCRIPTOR.message_types_by_name['SpeedControls'] = _SPEEDCONTROLS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeedControl = _reflection.GeneratedProtocolMessageType('SpeedControl', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDCONTROL,
  '__module__' : 'modules.map.proto.map_speed_control_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.SpeedControl)
  })
_sym_db.RegisterMessage(SpeedControl)

SpeedControls = _reflection.GeneratedProtocolMessageType('SpeedControls', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDCONTROLS,
  '__module__' : 'modules.map.proto.map_speed_control_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.SpeedControls)
  })
_sym_db.RegisterMessage(SpeedControls)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/feature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.map.proto import map_lane_pb2 as modules_dot_map_dot_proto_dot_map__lane__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2
from modules.prediction.proto import lane_graph_pb2 as modules_dot_prediction_dot_proto_dot_lane__graph__pb2
from modules.prediction.proto import prediction_point_pb2 as modules_dot_prediction_dot_proto_dot_prediction__point__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/feature.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/prediction/proto/feature.proto\x12\x11\x61pollo.prediction\x1a#modules/common/proto/geometry.proto\x1a$modules/common/proto/pnc_point.proto\x1a modules/map/proto/map_lane.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\x1a)modules/prediction/proto/lane_graph.proto\x1a/modules/prediction/proto/prediction_point.proto\"\xc4\x02\n\x04Lane\x12<\n\x14\x63urrent_lane_feature\x18\x01 \x03(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12\x34\n\x0clane_feature\x18\x02 \x01(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12;\n\x13nearby_lane_feature\x18\x03 \x03(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12\x30\n\nlane_graph\x18\x04 \x01(\x0b\x32\x1c.apollo.prediction.LaneGraph\x12\x38\n\x12lane_graph_ordered\x18\x05 \x01(\x0b\x32\x1c.apollo.prediction.LaneGraph\x12\x1f\n\x17label_update_time_delta\x18\x1a \x01(\x01\"\xef\x01\n\x0bLaneFeature\x12\x0f\n\x07lane_id\x18\x01 \x01(\t\x12\x16\n\x0elane_turn_type\x18\x02 \x01(\r\x12\x0e\n\x06lane_s\x18\x03 \x01(\x01\x12\x0e\n\x06lane_l\x18\x04 \x01(\x01\x12\x12\n\nangle_diff\x18\x05 \x01(\x01\x12\x1d\n\x15\x64ist_to_left_boundary\x18\x06 \x01(\x01\x12\x1e\n\x16\x64ist_to_right_boundary\x18\x07 \x01(\x01\x12\x14\n\x0clane_heading\x18\x08 \x01(\x01\x12.\n\tlane_type\x18\t \x01(\x0e\x32\x1b.apollo.hdmap.Lane.LaneType\"}\n\x0cJunctionExit\x12\x14\n\x0c\x65xit_lane_id\x18\x01 \x01(\t\x12-\n\rexit_position\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x14\n\x0c\x65xit_heading\x18\x03 \x01(\x01\x12\x12\n\nexit_width\x18\x04 \x01(\x01\"\x9d\x02\n\x0fJunctionFeature\x12\x13\n\x0bjunction_id\x18\x01 \x01(\t\x12\x16\n\x0ejunction_range\x18\x02 \x01(\x01\x12\x32\n\nenter_lane\x18\x03 \x01(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12\x36\n\rjunction_exit\x18\x04 \x03(\x0b\x32\x1f.apollo.prediction.JunctionExit\x12\x1c\n\x14junction_mlp_feature\x18\x05 \x03(\x01\x12\x1a\n\x12junction_mlp_label\x18\x06 \x03(\x05\x12 \n\x18junction_mlp_probability\x18\x07 \x03(\x01\x12\x15\n\rstart_lane_id\x18\x08 \x03(\t\"\x8b\x01\n\x10ObstaclePriority\x12\x46\n\x08priority\x18\x19 \x01(\x0e\x32,.apollo.prediction.ObstaclePriority.Priority:\x06NORMAL\"/\n\x08Priority\x12\x0b\n\x07\x43\x41UTION\x10\x01\x12\n\n\x06NORMAL\x10\x02\x12\n\n\x06IGNORE\x10\x03\"[\n\nTrajectory\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12\x38\n\x10trajectory_point\x18\x02 \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"\x9b\n\n\x07\x46\x65\x61ture\x12\n\n\x02id\x18\x01 \x01(\x05\x12-\n\rpolygon_point\x18\x1e \x03(\x0b\x32\x16.apollo.common.Point3D\x12(\n\x08position\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12.\n\x0e\x66ront_position\x18\x1b \x01(\x0b\x32\x16.apollo.common.Point3D\x12(\n\x08velocity\x18\x03 \x01(\x0b\x32\x16.apollo.common.Point3D\x12,\n\x0craw_velocity\x18\x1c \x01(\x0b\x32\x16.apollo.common.Point3D\x12,\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x18\n\x10velocity_heading\x18\x05 \x01(\x01\x12\r\n\x05speed\x18\x06 \x01(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x07 \x01(\x01\x12\r\n\x05theta\x18\x08 \x01(\x01\x12\x0e\n\x06length\x18\t \x01(\x01\x12\r\n\x05width\x18\n \x01(\x01\x12\x0e\n\x06height\x18\x0b \x01(\x01\x12\x15\n\rtracking_time\x18\x0c \x01(\x01\x12\x11\n\ttimestamp\x18\r \x01(\x01\x12%\n\x04lane\x18\x0e \x01(\x0b\x32\x17.apollo.prediction.Lane\x12<\n\x10junction_feature\x18\x1a \x01(\x0b\x32\".apollo.prediction.JunctionFeature\x12*\n\nt_position\x18\x10 \x01(\x0b\x32\x16.apollo.common.Point3D\x12.\n\nt_velocity\x18\x11 \x01(\x0b\x32\x16.apollo.common.Point3DB\x02\x18\x01\x12\x1e\n\x12t_velocity_heading\x18\x12 \x01(\x01\x42\x02\x18\x01\x12\x13\n\x07t_speed\x18\x13 \x01(\x01\x42\x02\x18\x01\x12\x32\n\x0et_acceleration\x18\x14 \x01(\x0b\x32\x16.apollo.common.Point3DB\x02\x18\x01\x12\x11\n\x05t_acc\x18\x15 \x01(\x01\x42\x02\x18\x01\x12\x17\n\x08is_still\x18\x16 \x01(\x08:\x05\x66\x61lse\x12\x38\n\x04type\x18\x17 \x01(\x0e\x32*.apollo.perception.PerceptionObstacle.Type\x12\x1f\n\x17label_update_time_delta\x18\x18 \x01(\x01\x12\x35\n\x08priority\x18\x19 \x01(\x0b\x32#.apollo.prediction.ObstaclePriority\x12\x1f\n\x10is_near_junction\x18\x1d \x01(\x08:\x05\x66\x61lse\x12N\n\x18\x66uture_trajectory_points\x18\x1f \x03(\x0b\x32,.apollo.prediction.PredictionTrajectoryPoint\x12N\n&short_term_predicted_trajectory_points\x18  \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12;\n\x14predicted_trajectory\x18! \x03(\x0b\x32\x1d.apollo.prediction.Trajectory\x12<\n\x14\x61\x64\x63_trajectory_point\x18\" \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12\x1b\n\x13surrounding_lane_id\x18# \x03(\t\x12\x16\n\x0ewithin_lane_id\x18$ \x03(\t\"[\n\x0fObstacleHistory\x12+\n\x07\x66\x65\x61ture\x18\x01 \x03(\x0b\x32\x1a.apollo.prediction.Feature\x12\x1b\n\x0cis_trainable\x18\x02 \x01(\x08:\x05\x66\x61lse\"\x95\x01\n\x08\x46rameEnv\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x37\n\x0b\x65go_history\x18\x02 \x01(\x0b\x32\".apollo.prediction.ObstacleHistory\x12=\n\x11obstacles_history\x18\x03 \x03(\x0b\x32\".apollo.prediction.ObstacleHistory'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__lane__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_lane__graph__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_prediction__point__pb2.DESCRIPTOR,])



_OBSTACLEPRIORITY_PRIORITY = _descriptor.EnumDescriptor(
  name='Priority',
  full_name='apollo.prediction.ObstaclePriority.Priority',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAUTION', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IGNORE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1391,
  serialized_end=1438,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLEPRIORITY_PRIORITY)


_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='apollo.prediction.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_lane_feature', full_name='apollo.prediction.Lane.current_lane_feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_feature', full_name='apollo.prediction.Lane.lane_feature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearby_lane_feature', full_name='apollo.prediction.Lane.nearby_lane_feature', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_graph', full_name='apollo.prediction.Lane.lane_graph', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_graph_ordered', full_name='apollo.prediction.Lane.lane_graph_ordered', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_update_time_delta', full_name='apollo.prediction.Lane.label_update_time_delta', index=5,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=639,
)


_LANEFEATURE = _descriptor.Descriptor(
  name='LaneFeature',
  full_name='apollo.prediction.LaneFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.prediction.LaneFeature.lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_turn_type', full_name='apollo.prediction.LaneFeature.lane_turn_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_s', full_name='apollo.prediction.LaneFeature.lane_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_l', full_name='apollo.prediction.LaneFeature.lane_l', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angle_diff', full_name='apollo.prediction.LaneFeature.angle_diff', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dist_to_left_boundary', full_name='apollo.prediction.LaneFeature.dist_to_left_boundary', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dist_to_right_boundary', full_name='apollo.prediction.LaneFeature.dist_to_right_boundary', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_heading', full_name='apollo.prediction.LaneFeature.lane_heading', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.prediction.LaneFeature.lane_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=881,
)


_JUNCTIONEXIT = _descriptor.Descriptor(
  name='JunctionExit',
  full_name='apollo.prediction.JunctionExit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exit_lane_id', full_name='apollo.prediction.JunctionExit.exit_lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_position', full_name='apollo.prediction.JunctionExit.exit_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_heading', full_name='apollo.prediction.JunctionExit.exit_heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_width', full_name='apollo.prediction.JunctionExit.exit_width', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1008,
)


_JUNCTIONFEATURE = _descriptor.Descriptor(
  name='JunctionFeature',
  full_name='apollo.prediction.JunctionFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='apollo.prediction.JunctionFeature.junction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_range', full_name='apollo.prediction.JunctionFeature.junction_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enter_lane', full_name='apollo.prediction.JunctionFeature.enter_lane', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_exit', full_name='apollo.prediction.JunctionFeature.junction_exit', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_mlp_feature', full_name='apollo.prediction.JunctionFeature.junction_mlp_feature', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_mlp_label', full_name='apollo.prediction.JunctionFeature.junction_mlp_label', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_mlp_probability', full_name='apollo.prediction.JunctionFeature.junction_mlp_probability', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_lane_id', full_name='apollo.prediction.JunctionFeature.start_lane_id', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1296,
)


_OBSTACLEPRIORITY = _descriptor.Descriptor(
  name='ObstaclePriority',
  full_name='apollo.prediction.ObstaclePriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='apollo.prediction.ObstaclePriority.priority', index=0,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSTACLEPRIORITY_PRIORITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1299,
  serialized_end=1438,
)


_TRAJECTORY = _descriptor.Descriptor(
  name='Trajectory',
  full_name='apollo.prediction.Trajectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.prediction.Trajectory.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.prediction.Trajectory.trajectory_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1531,
)


_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='apollo.prediction.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.prediction.Feature.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon_point', full_name='apollo.prediction.Feature.polygon_point', index=1,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.prediction.Feature.position', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_position', full_name='apollo.prediction.Feature.front_position', index=3,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.prediction.Feature.velocity', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_velocity', full_name='apollo.prediction.Feature.raw_velocity', index=5,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.prediction.Feature.acceleration', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_heading', full_name='apollo.prediction.Feature.velocity_heading', index=7,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.prediction.Feature.speed', index=8,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc', full_name='apollo.prediction.Feature.acc', index=9,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.prediction.Feature.theta', index=10,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.prediction.Feature.length', index=11,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.prediction.Feature.width', index=12,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.prediction.Feature.height', index=13,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracking_time', full_name='apollo.prediction.Feature.tracking_time', index=14,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.Feature.timestamp', index=15,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane', full_name='apollo.prediction.Feature.lane', index=16,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_feature', full_name='apollo.prediction.Feature.junction_feature', index=17,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_position', full_name='apollo.prediction.Feature.t_position', index=18,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_velocity', full_name='apollo.prediction.Feature.t_velocity', index=19,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_velocity_heading', full_name='apollo.prediction.Feature.t_velocity_heading', index=20,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_speed', full_name='apollo.prediction.Feature.t_speed', index=21,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_acceleration', full_name='apollo.prediction.Feature.t_acceleration', index=22,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_acc', full_name='apollo.prediction.Feature.t_acc', index=23,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_still', full_name='apollo.prediction.Feature.is_still', index=24,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.prediction.Feature.type', index=25,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_update_time_delta', full_name='apollo.prediction.Feature.label_update_time_delta', index=26,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='apollo.prediction.Feature.priority', index=27,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_near_junction', full_name='apollo.prediction.Feature.is_near_junction', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future_trajectory_points', full_name='apollo.prediction.Feature.future_trajectory_points', index=29,
      number=31, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_term_predicted_trajectory_points', full_name='apollo.prediction.Feature.short_term_predicted_trajectory_points', index=30,
      number=32, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predicted_trajectory', full_name='apollo.prediction.Feature.predicted_trajectory', index=31,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_trajectory_point', full_name='apollo.prediction.Feature.adc_trajectory_point', index=32,
      number=34, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surrounding_lane_id', full_name='apollo.prediction.Feature.surrounding_lane_id', index=33,
      number=35, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='within_lane_id', full_name='apollo.prediction.Feature.within_lane_id', index=34,
      number=36, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=2841,
)


_OBSTACLEHISTORY = _descriptor.Descriptor(
  name='ObstacleHistory',
  full_name='apollo.prediction.ObstacleHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='apollo.prediction.ObstacleHistory.feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_trainable', full_name='apollo.prediction.ObstacleHistory.is_trainable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2843,
  serialized_end=2934,
)


_FRAMEENV = _descriptor.Descriptor(
  name='FrameEnv',
  full_name='apollo.prediction.FrameEnv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.FrameEnv.timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ego_history', full_name='apollo.prediction.FrameEnv.ego_history', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacles_history', full_name='apollo.prediction.FrameEnv.obstacles_history', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2937,
  serialized_end=3086,
)

_LANE.fields_by_name['current_lane_feature'].message_type = _LANEFEATURE
_LANE.fields_by_name['lane_feature'].message_type = _LANEFEATURE
_LANE.fields_by_name['nearby_lane_feature'].message_type = _LANEFEATURE
_LANE.fields_by_name['lane_graph'].message_type = modules_dot_prediction_dot_proto_dot_lane__graph__pb2._LANEGRAPH
_LANE.fields_by_name['lane_graph_ordered'].message_type = modules_dot_prediction_dot_proto_dot_lane__graph__pb2._LANEGRAPH
_LANEFEATURE.fields_by_name['lane_type'].enum_type = modules_dot_map_dot_proto_dot_map__lane__pb2._LANE_LANETYPE
_JUNCTIONEXIT.fields_by_name['exit_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_JUNCTIONFEATURE.fields_by_name['enter_lane'].message_type = _LANEFEATURE
_JUNCTIONFEATURE.fields_by_name['junction_exit'].message_type = _JUNCTIONEXIT
_OBSTACLEPRIORITY.fields_by_name['priority'].enum_type = _OBSTACLEPRIORITY_PRIORITY
_OBSTACLEPRIORITY_PRIORITY.containing_type = _OBSTACLEPRIORITY
_TRAJECTORY.fields_by_name['trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_FEATURE.fields_by_name['polygon_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['front_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['raw_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['lane'].message_type = _LANE
_FEATURE.fields_by_name['junction_feature'].message_type = _JUNCTIONFEATURE
_FEATURE.fields_by_name['t_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['t_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['t_acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['type'].enum_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE_TYPE
_FEATURE.fields_by_name['priority'].message_type = _OBSTACLEPRIORITY
_FEATURE.fields_by_name['future_trajectory_points'].message_type = modules_dot_prediction_dot_proto_dot_prediction__point__pb2._PREDICTIONTRAJECTORYPOINT
_FEATURE.fields_by_name['short_term_predicted_trajectory_points'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_FEATURE.fields_by_name['predicted_trajectory'].message_type = _TRAJECTORY
_FEATURE.fields_by_name['adc_trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_OBSTACLEHISTORY.fields_by_name['feature'].message_type = _FEATURE
_FRAMEENV.fields_by_name['ego_history'].message_type = _OBSTACLEHISTORY
_FRAMEENV.fields_by_name['obstacles_history'].message_type = _OBSTACLEHISTORY
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
DESCRIPTOR.message_types_by_name['LaneFeature'] = _LANEFEATURE
DESCRIPTOR.message_types_by_name['JunctionExit'] = _JUNCTIONEXIT
DESCRIPTOR.message_types_by_name['JunctionFeature'] = _JUNCTIONFEATURE
DESCRIPTOR.message_types_by_name['ObstaclePriority'] = _OBSTACLEPRIORITY
DESCRIPTOR.message_types_by_name['Trajectory'] = _TRAJECTORY
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['ObstacleHistory'] = _OBSTACLEHISTORY
DESCRIPTOR.message_types_by_name['FrameEnv'] = _FRAMEENV
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {
  'DESCRIPTOR' : _LANE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Lane)
  })
_sym_db.RegisterMessage(Lane)

LaneFeature = _reflection.GeneratedProtocolMessageType('LaneFeature', (_message.Message,), {
  'DESCRIPTOR' : _LANEFEATURE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LaneFeature)
  })
_sym_db.RegisterMessage(LaneFeature)

JunctionExit = _reflection.GeneratedProtocolMessageType('JunctionExit', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTIONEXIT,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.JunctionExit)
  })
_sym_db.RegisterMessage(JunctionExit)

JunctionFeature = _reflection.GeneratedProtocolMessageType('JunctionFeature', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTIONFEATURE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.JunctionFeature)
  })
_sym_db.RegisterMessage(JunctionFeature)

ObstaclePriority = _reflection.GeneratedProtocolMessageType('ObstaclePriority', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLEPRIORITY,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ObstaclePriority)
  })
_sym_db.RegisterMessage(ObstaclePriority)

Trajectory = _reflection.GeneratedProtocolMessageType('Trajectory', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORY,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Trajectory)
  })
_sym_db.RegisterMessage(Trajectory)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Feature)
  })
_sym_db.RegisterMessage(Feature)

ObstacleHistory = _reflection.GeneratedProtocolMessageType('ObstacleHistory', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLEHISTORY,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ObstacleHistory)
  })
_sym_db.RegisterMessage(ObstacleHistory)

FrameEnv = _reflection.GeneratedProtocolMessageType('FrameEnv', (_message.Message,), {
  'DESCRIPTOR' : _FRAMEENV,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.FrameEnv)
  })
_sym_db.RegisterMessage(FrameEnv)


_FEATURE.fields_by_name['t_velocity']._options = None
_FEATURE.fields_by_name['t_velocity_heading']._options = None
_FEATURE.fields_by_name['t_speed']._options = None
_FEATURE.fields_by_name['t_acceleration']._options = None
_FEATURE.fields_by_name['t_acc']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/hmi_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/hmi_config.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/dreamview/proto/hmi_config.proto\x12\x10\x61pollo.dreamview\"\xc0\x02\n\tHMIConfig\x12\x35\n\x05modes\x18\x01 \x03(\x0b\x32&.apollo.dreamview.HMIConfig.ModesEntry\x12\x33\n\x04maps\x18\x02 \x03(\x0b\x32%.apollo.dreamview.HMIConfig.MapsEntry\x12;\n\x08vehicles\x18\x03 \x03(\x0b\x32).apollo.dreamview.HMIConfig.VehiclesEntry\x1a,\n\nModesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tMapsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rVehiclesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x0bVehicleData\x12:\n\ndata_files\x18\x01 \x03(\x0b\x32&.apollo.dreamview.VehicleData.DataFile\x1a\x32\n\x08\x44\x61taFile\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x11\n\tdest_path\x18\x02 \x01(\t*\xb1\x01\n\tHMIAction\x12\x08\n\x04NONE\x10\x00\x12\x0e\n\nSETUP_MODE\x10\x01\x12\x0e\n\nRESET_MODE\x10\x02\x12\x13\n\x0f\x45NTER_AUTO_MODE\x10\x03\x12\r\n\tDISENGAGE\x10\x04\x12\x0f\n\x0b\x43HANGE_MODE\x10\x05\x12\x0e\n\nCHANGE_MAP\x10\x06\x12\x12\n\x0e\x43HANGE_VEHICLE\x10\x07\x12\x10\n\x0cSTART_MODULE\x10\x08\x12\x0f\n\x0bSTOP_MODULE\x10\t'
)

_HMIACTION = _descriptor.EnumDescriptor(
  name='HMIAction',
  full_name='apollo.dreamview.HMIAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SETUP_MODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESET_MODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTER_AUTO_MODE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_MODE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_MAP', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_VEHICLE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='START_MODULE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_MODULE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=513,
  serialized_end=690,
)
_sym_db.RegisterEnumDescriptor(_HMIACTION)

HMIAction = enum_type_wrapper.EnumTypeWrapper(_HMIACTION)
NONE = 0
SETUP_MODE = 1
RESET_MODE = 2
ENTER_AUTO_MODE = 3
DISENGAGE = 4
CHANGE_MODE = 5
CHANGE_MAP = 6
CHANGE_VEHICLE = 7
START_MODULE = 8
STOP_MODULE = 9



_HMICONFIG_MODESENTRY = _descriptor.Descriptor(
  name='ModesEntry',
  full_name='apollo.dreamview.HMIConfig.ModesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIConfig.ModesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIConfig.ModesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=289,
)

_HMICONFIG_MAPSENTRY = _descriptor.Descriptor(
  name='MapsEntry',
  full_name='apollo.dreamview.HMIConfig.MapsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIConfig.MapsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIConfig.MapsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=334,
)

_HMICONFIG_VEHICLESENTRY = _descriptor.Descriptor(
  name='VehiclesEntry',
  full_name='apollo.dreamview.HMIConfig.VehiclesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIConfig.VehiclesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIConfig.VehiclesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=383,
)

_HMICONFIG = _descriptor.Descriptor(
  name='HMIConfig',
  full_name='apollo.dreamview.HMIConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modes', full_name='apollo.dreamview.HMIConfig.modes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maps', full_name='apollo.dreamview.HMIConfig.maps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicles', full_name='apollo.dreamview.HMIConfig.vehicles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HMICONFIG_MODESENTRY, _HMICONFIG_MAPSENTRY, _HMICONFIG_VEHICLESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=383,
)


_VEHICLEDATA_DATAFILE = _descriptor.Descriptor(
  name='DataFile',
  full_name='apollo.dreamview.VehicleData.DataFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_path', full_name='apollo.dreamview.VehicleData.DataFile.source_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dest_path', full_name='apollo.dreamview.VehicleData.DataFile.dest_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=510,
)

_VEHICLEDATA = _descriptor.Descriptor(
  name='VehicleData',
  full_name='apollo.dreamview.VehicleData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_files', full_name='apollo.dreamview.VehicleData.data_files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VEHICLEDATA_DATAFILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=510,
)

_HMICONFIG_MODESENTRY.containing_type = _HMICONFIG
_HMICONFIG_MAPSENTRY.containing_type = _HMICONFIG
_HMICONFIG_VEHICLESENTRY.containing_type = _HMICONFIG
_HMICONFIG.fields_by_name['modes'].message_type = _HMICONFIG_MODESENTRY
_HMICONFIG.fields_by_name['maps'].message_type = _HMICONFIG_MAPSENTRY
_HMICONFIG.fields_by_name['vehicles'].message_type = _HMICONFIG_VEHICLESENTRY
_VEHICLEDATA_DATAFILE.containing_type = _VEHICLEDATA
_VEHICLEDATA.fields_by_name['data_files'].message_type = _VEHICLEDATA_DATAFILE
DESCRIPTOR.message_types_by_name['HMIConfig'] = _HMICONFIG
DESCRIPTOR.message_types_by_name['VehicleData'] = _VEHICLEDATA
DESCRIPTOR.enum_types_by_name['HMIAction'] = _HMIACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HMIConfig = _reflection.GeneratedProtocolMessageType('HMIConfig', (_message.Message,), {

  'ModesEntry' : _reflection.GeneratedProtocolMessageType('ModesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMICONFIG_MODESENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIConfig.ModesEntry)
    })
  ,

  'MapsEntry' : _reflection.GeneratedProtocolMessageType('MapsEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMICONFIG_MAPSENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIConfig.MapsEntry)
    })
  ,

  'VehiclesEntry' : _reflection.GeneratedProtocolMessageType('VehiclesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMICONFIG_VEHICLESENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIConfig.VehiclesEntry)
    })
  ,
  'DESCRIPTOR' : _HMICONFIG,
  '__module__' : 'modules.dreamview.proto.hmi_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIConfig)
  })
_sym_db.RegisterMessage(HMIConfig)
_sym_db.RegisterMessage(HMIConfig.ModesEntry)
_sym_db.RegisterMessage(HMIConfig.MapsEntry)
_sym_db.RegisterMessage(HMIConfig.VehiclesEntry)

VehicleData = _reflection.GeneratedProtocolMessageType('VehicleData', (_message.Message,), {

  'DataFile' : _reflection.GeneratedProtocolMessageType('DataFile', (_message.Message,), {
    'DESCRIPTOR' : _VEHICLEDATA_DATAFILE,
    '__module__' : 'modules.dreamview.proto.hmi_config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.VehicleData.DataFile)
    })
  ,
  'DESCRIPTOR' : _VEHICLEDATA,
  '__module__' : 'modules.dreamview.proto.hmi_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.VehicleData)
  })
_sym_db.RegisterMessage(VehicleData)
_sym_db.RegisterMessage(VehicleData.DataFile)


_HMICONFIG_MODESENTRY._options = None
_HMICONFIG_MAPSENTRY._options = None
_HMICONFIG_VEHICLESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/lidar_component_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/lidar_component_config.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=modules/perception/onboard/proto/lidar_component_config.proto\x12\x19\x61pollo.perception.onboard\"\xb3\x01\n LidarSegmentationComponentConfig\x12\x13\n\x0bsensor_name\x18\x01 \x01(\t\x12\x14\n\x0c\x65nable_hdmap\x18\x02 \x01(\x08\x12\x1d\n\x15lidar_query_tf_offset\x18\x03 \x01(\x01\x12(\n lidar2novatel_tf2_child_frame_id\x18\x04 \x01(\t\x12\x1b\n\x13output_channel_name\x18\x05 \x01(\t\"\xb0\x01\n\x1dLidarDetectionComponentConfig\x12\x13\n\x0bsensor_name\x18\x01 \x01(\t\x12\x14\n\x0c\x65nable_hdmap\x18\x02 \x01(\x08\x12\x1d\n\x15lidar_query_tf_offset\x18\x03 \x01(\x01\x12(\n lidar2novatel_tf2_child_frame_id\x18\x04 \x01(\t\x12\x1b\n\x13output_channel_name\x18\x05 \x01(\t\"X\n\x1fLidarRecognitionComponentConfig\x12\x18\n\x10main_sensor_name\x18\x01 \x01(\t\x12\x1b\n\x13output_channel_name\x18\x02 \x01(\t'
)




_LIDARSEGMENTATIONCOMPONENTCONFIG = _descriptor.Descriptor(
  name='LidarSegmentationComponentConfig',
  full_name='apollo.perception.onboard.LidarSegmentationComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_name', full_name='apollo.perception.onboard.LidarSegmentationComponentConfig.sensor_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hdmap', full_name='apollo.perception.onboard.LidarSegmentationComponentConfig.enable_hdmap', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_query_tf_offset', full_name='apollo.perception.onboard.LidarSegmentationComponentConfig.lidar_query_tf_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar2novatel_tf2_child_frame_id', full_name='apollo.perception.onboard.LidarSegmentationComponentConfig.lidar2novatel_tf2_child_frame_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_channel_name', full_name='apollo.perception.onboard.LidarSegmentationComponentConfig.output_channel_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=272,
)


_LIDARDETECTIONCOMPONENTCONFIG = _descriptor.Descriptor(
  name='LidarDetectionComponentConfig',
  full_name='apollo.perception.onboard.LidarDetectionComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_name', full_name='apollo.perception.onboard.LidarDetectionComponentConfig.sensor_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hdmap', full_name='apollo.perception.onboard.LidarDetectionComponentConfig.enable_hdmap', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_query_tf_offset', full_name='apollo.perception.onboard.LidarDetectionComponentConfig.lidar_query_tf_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar2novatel_tf2_child_frame_id', full_name='apollo.perception.onboard.LidarDetectionComponentConfig.lidar2novatel_tf2_child_frame_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_channel_name', full_name='apollo.perception.onboard.LidarDetectionComponentConfig.output_channel_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=451,
)


_LIDARRECOGNITIONCOMPONENTCONFIG = _descriptor.Descriptor(
  name='LidarRecognitionComponentConfig',
  full_name='apollo.perception.onboard.LidarRecognitionComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='main_sensor_name', full_name='apollo.perception.onboard.LidarRecognitionComponentConfig.main_sensor_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_channel_name', full_name='apollo.perception.onboard.LidarRecognitionComponentConfig.output_channel_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=541,
)

DESCRIPTOR.message_types_by_name['LidarSegmentationComponentConfig'] = _LIDARSEGMENTATIONCOMPONENTCONFIG
DESCRIPTOR.message_types_by_name['LidarDetectionComponentConfig'] = _LIDARDETECTIONCOMPONENTCONFIG
DESCRIPTOR.message_types_by_name['LidarRecognitionComponentConfig'] = _LIDARRECOGNITIONCOMPONENTCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LidarSegmentationComponentConfig = _reflection.GeneratedProtocolMessageType('LidarSegmentationComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIDARSEGMENTATIONCOMPONENTCONFIG,
  '__module__' : 'modules.perception.onboard.proto.lidar_component_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.LidarSegmentationComponentConfig)
  })
_sym_db.RegisterMessage(LidarSegmentationComponentConfig)

LidarDetectionComponentConfig = _reflection.GeneratedProtocolMessageType('LidarDetectionComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIDARDETECTIONCOMPONENTCONFIG,
  '__module__' : 'modules.perception.onboard.proto.lidar_component_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.LidarDetectionComponentConfig)
  })
_sym_db.RegisterMessage(LidarDetectionComponentConfig)

LidarRecognitionComponentConfig = _reflection.GeneratedProtocolMessageType('LidarRecognitionComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIDARRECOGNITIONCOMPONENTCONFIG,
  '__module__' : 'modules.perception.onboard.proto.lidar_component_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.LidarRecognitionComponentConfig)
  })
_sym_db.RegisterMessage(LidarRecognitionComponentConfig)


# @@protoc_insertion_point(module_scope)
